#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.space_analyses_interfaces.distance import Distance
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Distances(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Distances
                | 
                | A collection of all Distance objects currently managed by the
                | application.
                | 
                | The method GetTechnologicalObject("Distances") on the root product, allows you
                | to retrieve this collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Distance)
        self.distances = com_object

    def add(self) -> Distance:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Add() As Distance
                | 
                |     Creates a Distance object which takes all products of the document into
                |     account and adds it to the Distances collection.
                | 
                |     Returns:
                |         The created Distance 
                |     Example:
                | 
                |              This example creates a new Distance in the TheDistances
                |              collection.
                |
                |             Dim NewDistance As Distance
                |             Set NewDistance = TheDistances.Add

        :rtype: Distance
        """
        return Distance(self.distances.Add())

    def add_from_sel(self) -> Distance:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func AddFromSel() As Distance
                | 
                |     Creates a Distance object which takes all products in the selection into
                |     account and adds it to the Distances collection.
                | 
                |     Returns:
                |         The created Distance 
                |     Example:
                | 
                |              This example creates a new Distance in the TheDistances
                |              collection.
                |
                |             Dim NewDistance As Distance
                |             Set NewDistance = TheDistances.AddFromSel

        :rtype: Distance
        """
        return Distance(self.distances.AddFromSel())

    def item(self, i_index: cat_variant) -> Distance:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(CATVariant iIndex) As Distance
                | 
                |     Returns a Distance object using its index or its name from the Distances
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Distance to retrieve from the
                |             collection of Distances. As a numerics, this index is the rank of the Distance
                |             in the collection. The index of the first Distance in the collection is 1, and
                |             the index of the last Distance is Count. As a string, it is the name you
                |             assigned to the Distance. 
                | 
                |     Example:
                | 
                |              This example retrieves in ThisDistance the ninth
                |              Distance,
                |             and in ThatDistance the Distance named
                |             Distance Of MyProduct from the TheDistances collection.
                |
                |             Dim ThisDistance As Distance
                |             Set ThisDistance = TheDistances.Item(9)
                |             Dim ThatDistance As Distance
                |             Set ThatDistance = TheDistances.Item("Distance Of MyProduct")

        :param cat_variant i_index:
        :rtype: Distance
        """
        return Distance(self.distances.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Distance object from the Distances collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Distance to remove from the collection
                |             of Distances. As a numerics, this index is the rank of the Distance in the
                |             collection. The index of the first Distance in the collection is 1, and the
                |             index of the last Distance is Count. As a string, it is the name you assigned
                |             to the Distance. 
                | 
                |     Example:
                | 
                |              The following example removes the tenth Distance and the Distance
                |              named
                |             Distance Of MyProduct from the TheDistances
                |             collection.
                |
                |             TheDistances.Remove(10)
                |             TheDistances.Remove("Distance Of MyProduct")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.distances.Remove(i_index)

    def __getitem__(self, n: int) -> Distance:
        if (n + 1) > self.count:
            raise StopIteration

        return Distance(self.distances.Item(n + 1))

    def __iter__(self) -> Iterator[Distance]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Distances(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_dimension import DrawingDimension
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.cat_tps_interfaces.dimension_limit import DimensionLimit


class NonSemanticDimension(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     NonSemanticDimension
                | 
                | Interface Managing Non Semantic Dimension.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.non_semantic_dimension = com_object

    def dimension_limit(self) -> DimensionLimit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DimensionLimit() As DimensionLimit
                | 
                |     Gets the Dimension on the DimensionLimit interface.
                | 
                |     Parameters:
                | 
                |         oDimLim
                |             The Dimension Limits.

        :rtype: DimensionLimit
        """
        return DimensionLimit(self.non_semantic_dimension.DimensionLimit())

    def get_2d_annot(self) -> DrawingDimension:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Get2dAnnot() As DrawingDimension
                | 
                |     Retrieves Drafting Dimension.
                | 
                |     Parameters:
                | 
                |         oDim
                |             The Drafting Dimension.

        :rtype: DrawingDimension
        """
        return DrawingDimension(self.non_semantic_dimension.Get2dAnnot())

    def has_dimension_limit(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasDimensionLimit() As boolean
                | 
                |     Checks if the Dimension has a Dimension Limit.
                | 
                |     Parameters:
                | 
                |         oHasDimLim
                | 
                |                 TRUE: Dimension Limit exists
                |                 FALSE: Dimension Limit does not exist

        :rtype: bool
        """
        return self.non_semantic_dimension.HasDimensionLimit()

    def __repr__(self):
        return f'NonSemanticDimension(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class FastenerWorkBench(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FastenerWorkBench
                | 
                | Interface DELMIAFastenerWorkBench It is a utility class to get fasteners and
                | groups from document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fastener_work_bench = com_object

    def curve_fasteners(self, o_curve_fastener_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CurveFasteners(CATSafeArrayVariant
                | oCurveFastenerArray)

        :param tuple o_curve_fastener_array:
        :rtype: None
        """
        return self.fastener_work_bench.CurveFasteners(o_curve_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'curve_fasteners'
        # # vba_code = """
        # # Public Function curve_fasteners(fastener_work_bench)
        # #     Dim oCurveFastenerArray (2)
        # #     fastener_work_bench.CurveFasteners oCurveFastenerArray
        # #     curve_fasteners = oCurveFastenerArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def fastener_groups(self, o_fastener_group_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FastenerGroups(CATSafeArrayVariant
                | oFastenerGroupArray)

        :param tuple o_fastener_group_array:
        :rtype: None
        """
        return self.fastener_work_bench.FastenerGroups(o_fastener_group_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'fastener_groups'
        # # vba_code = """
        # # Public Function fastener_groups(fastener_work_bench)
        # #     Dim oFastenerGroupArray (2)
        # #     fastener_work_bench.FastenerGroups oFastenerGroupArray
        # #     fastener_groups = oFastenerGroupArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_curve_fasteners(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfCurveFasteners() As long

        :rtype: int
        """
        return self.fastener_work_bench.GetNumberOfCurveFasteners()

    def get_number_of_fastener_groups(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfFastenerGroups() As long

        :rtype: int
        """
        return self.fastener_work_bench.GetNumberOfFastenerGroups()

    def get_number_of_point_fasteners(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfPointFasteners() As long

        :rtype: int
        """
        return self.fastener_work_bench.GetNumberOfPointFasteners()

    def point_fasteners(self, o_point_fastener_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PointFasteners(CATSafeArrayVariant
                | oPointFastenerArray)

        :param tuple o_point_fastener_array:
        :rtype: None
        """
        return self.fastener_work_bench.PointFasteners(o_point_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'point_fasteners'
        # # vba_code = """
        # # Public Function point_fasteners(fastener_work_bench)
        # #     Dim oPointFastenerArray (2)
        # #     fastener_work_bench.PointFasteners oPointFastenerArray
        # #     point_fasteners = oPointFastenerArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FastenerWorkBench(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPSpatial(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspSpatial
                | 
                | Represents the Psp Spatial object.
                | Role: To access Plant Ship spatial object information.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_spatial = com_object

    @property
    def physicals(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Physicals() As PspListOfObjects (Read Only)
                | 
                |     Returns all physical objects associated to this spatial
                |     object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspSpatial
                |          Dim objArg1 As CATIAPspListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.Physicals

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_spatial.Physicals)

    def get_connected_physicals(
            self,
            isp_node: AnyObject,
            o_l_psp_connectors: PSPListOfObjects,
            o_l_psp_physicals: PSPListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetConnectedPhysicals(AnyObject ispNode,
                | PspListOfObjects oLPspConnectors,
                | PspListOfObjects oLPspPhysicals)
                | 
                |     Return all physical objects associated to this extremity
                |     nodes
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspSpatial
                |          Dim objArg1 As CATIABase
                |          Dim objArg2 As CATIAPspListOfObjects
                |          Dim objArg3 As CATIAPspListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf
                |          Set objArg1 = oLPspConnectors
                |          Set objArg1 = oLPspPhysicals GetConnectedPhysicals

        :param AnyObject isp_node:
        :param PSPListOfObjects o_l_psp_connectors:
        :param PSPListOfObjects o_l_psp_physicals:
        :rtype: None
        """
        return self.psp_spatial.GetConnectedPhysicals(
            isp_node.com_object,
            o_l_psp_connectors.com_object,
            o_l_psp_physicals.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_connected_physicals'
        # # vba_code = """
        # # Public Function get_connected_physicals(psp_spatial)
        # #     Dim ispNode (2)
        # #     psp_spatial.GetConnectedPhysicals ispNode
        # #     get_connected_physicals = ispNode
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPSpatial(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingInsert(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingInsert
                | 
                | The interface to access a CATIAManufacturingInsert.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_insert = com_object

    @property
    def insert_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property InsertType() As CATBSTR (Read Only)
                | 
                |     Return the technological type of a the insert. Example: The following
                |     example return the insert type theType of to the insert CurrentInsert
                |     theType=CurrentInsert.InsertType.

        :rtype: str
        """

        return self.manufacturing_insert.InsertType

    @property
    def number_of_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfAttributes() As short (Read Only)
                | 
                |     Give the Number of attributes of an insert object.
                |
                |     Example: The following example returns the Number of attributes of the
                |     insert object CurrentInsert.
                |
                |     Number = CurrentInsert.NumberOfAttributes.

        :rtype: int
        """

        return self.manufacturing_insert.NumberOfAttributes

    def get_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retrieve by is name the attribute of an insert object. Each attribute is a
                |     CKE object. Example: The following example retreives in MachiningQuality the
                |     attribute MfgMachiningQuality of the insert CurrentInsert
                | 
                |      Set MachiningQuality = CurrentInsert.GetAttribute(MfgMachiningQuality).

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_insert.GetAttribute(i_attribute))

    def get_attribute_nls_name(self, i_attribut_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttributeNLSName(CATBSTR iAttributName) As CATBSTR
                | 
                |     Gives the NLS value of an insert object
                |
                |     Example: The following example gives in NLSresult the NLS value of the "MFG_COMMENT"
                |     attributes of the insert CurrentInsert
                |
                |     NLSresult = CurrentInsert.GetAttributeNLSName("MFG_COMMENT").

        :param str i_attribut_name:
        :rtype: str
        """
        return self.manufacturing_insert.GetAttributeNLSName(i_attribut_name)

    def get_list_of_attribute_units(self, o_list_of_attribute_units: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributeUnits(CATSafeArrayVariant
                | oListOfAttributeUnits)
                | 
                |     Retrieve the list of attribute units of an insert object. The number of
                |     items in the output array is equal to the number of attributes of the insert.
                |     When an attribute has no unit definition, the corresponding unit item in the
                |     output array is a blank string. Example: The following example retrieves in
                |     TabAttributeUnits the list of attribute units of the insert object
                |     CurrentInsert call CurrentInsert.GetListOfAttributeUnits(TabAttributeUnits).

        :param tuple o_list_of_attribute_units:
        :rtype: None
        """
        return self.manufacturing_insert.GetListOfAttributeUnits(o_list_of_attribute_units)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attribute_units'
        # # vba_code = """
        # # Public Function get_list_of_attribute_units(manufacturing_insert)
        # #     Dim oListOfAttributeUnits (2)
        # #     manufacturing_insert.GetListOfAttributeUnits oListOfAttributeUnits
        # #     get_list_of_attribute_units = oListOfAttributeUnits
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of attributes of an insert object. Each attribute is
                |     returned as the name of a CKE object. Example: The following example retrieves
                |     in TabAttributes the list of attributes of the insert object CurrentInsert call
                |     CurrentInsert.GetListOfAttributes(TabAttributes).

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_insert.GetListOfAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attributes'
        # # vba_code = """
        # # Public Function get_list_of_attributes(manufacturing_insert)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_insert.GetListOfAttributes oListOfAttributes
        # #     get_list_of_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingInsert(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad


class ABQFilmCondition(ABQLoad):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQLoad
                |                         ABQFilmCondition
                | 
                | Represents an Abaqus film condition (ABQFilmCondition) object.
                | Role: Access an Abaqus film condition object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_film_condition = com_object

    @property
    def apply_user_subroutine(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyUserSubroutine() As boolean
                | 
                |     Sets or returns the user subroutine flag.
                | 
                |     Returns:
                |         A boolean specifying whether a nonuniform film coefficient is defined
                |         in user subroutine FILM.

        :rtype: bool
        """

        return self.abq_film_condition.ApplyUserSubroutine

    @apply_user_subroutine.setter
    def apply_user_subroutine(self, value: bool):
        """
        :param bool value:
        """

        self.abq_film_condition.ApplyUserSubroutine = value

    @property
    def dependencies(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property dependencies() As long (Read Only)
                | 
                |     Returns the number of temperature-dependent film
                |     coefficients.
                | 
                |     Returns:
                |         The number of temperature-dependent film coefficients.

        :rtype: int
        """

        return self.abq_film_condition.dependencies

    @property
    def film_coefficient(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property filmCoeff() As double
                | 
                |     Sets or returns the reference film coefficient if the film condition is not
                |     temperature dependent.
                | 
                |     Returns:
                |         The reference film coefficient if the film condition is not temperature
                |         dependent.

        :rtype: float
        """

        return self.abq_film_condition.filmCoeff

    @film_coefficient.setter
    def film_coefficient(self, value: float):
        """
        :param float value:
        """

        self.abq_film_condition.filmCoeff = value

    @property
    def sink_temperature(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property sinkTemperature() As double
                | 
                |     Sets or returns the reference sink temperature.
                | 
                |     Returns:
                |         The reference sink temperature.

        :rtype: float
        """

        return self.abq_film_condition.sinkTemperature

    @sink_temperature.setter
    def sink_temperature(self, value: float):
        """
        :param float value:
        """

        self.abq_film_condition.sinkTemperature = value

    @property
    def temperature_dependency(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property temperatureDependency() As boolean
                | 
                |     Sets or returns the temperature dependency.
                | 
                |     Returns:
                |         A boolean specifying whether the film condition is dependent on
                |         temperature.

        :rtype: bool
        """

        return self.abq_film_condition.temperatureDependency

    @temperature_dependency.setter
    def temperature_dependency(self, value: bool):
        """
        :param bool value:
        """

        self.abq_film_condition.temperatureDependency = value

    def add_temp_dependent_film_coeff_table(self, i_film_coeff: tuple, i_temperature: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddTempDependentFilmCoeffTable(CATSafeArrayVariant
                | iFilmCoeff,
                | CATSafeArrayVariant iTemperature)
                | 
                |     Adds a list of temperature dependent film coefficients if the film
                |     condition is temperature dependent. The number of values in both of the
                |     parameters should match. If either list contains extra values, the extra values
                |     are discarded.
                | 
                |     Parameters:
                | 
                |         iFilmCoeff
                |             The list of film coefficients.
                |         iTemperature
                |             The list of temperatures.

        :param tuple i_film_coeff:
        :param tuple i_temperature:
        :rtype: None
        """
        return self.abq_film_condition.AddTempDependentFilmCoeffTable(i_film_coeff, i_temperature)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_temp_dependent_film_coeff_table'
        # # vba_code = """
        # # Public Function add_temp_dependent_film_coeff_table(abq_film_condition)
        # #     Dim iFilmCoeff (2)
        # #     abq_film_condition.AddTempDependentFilmCoeffTable iFilmCoeff
        # #     add_temp_dependent_film_coeff_table = iFilmCoeff
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_name_of_film_coeff_amplitude(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNameOfFilmCoeffAmplitude(CATBSTR ofilmAmplitude)
                | 
                |     Returns the name of the amplitude that contains the variation of the the
                |     film coefficient with time.
                | 
                |     Parameters:
                | 
                |         ofilmAmplitude
                |             The name of the amplitude that contains the variation of the the
                |             film coefficient with time.

        :param str ofilm_amplitude:
        :rtype: None
        """
        return self.abq_film_condition.GetNameOfFilmCoeffAmplitude()

    def get_name_of_sink_amplitude(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetNameOfSinkAmplitude(CATBSTR osinkAmplitude)
                | 
                |     Returns the name of the amplitude that contains the variation of the sink
                |     temperature with time.
                | 
                |     Parameters:
                | 
                |         osinkAmplitude
                |             The name of the amplitude that contains the variation of the sink
                |             temperature with time.

        :param str osink_amplitude:
        :rtype: None
        """
        return self.abq_film_condition.GetNameOfSinkAmplitude()

    def get_temp_dependent_film_coeff_table(self) -> list:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTempDependentFilmCoeffTable(CATSafeArrayVariant
                | oFilmCoeff,
                | CATSafeArrayVariant oTemperature)
                | 
                |     Returns a list of temperature dependent film coefficients if the film
                |     condition is temperature dependent.
                | 
                |     Parameters:
                | 
                |         oFilmCoeff
                |             The list of film coefficients.
                |         oTemperature
                |             The list of temperatures.

        :param tuple o_film_coeff:
        :param tuple o_temperature:
        :rtype: None
        """
        return self.abq_film_condition.GetTempDependentFilmCoeffTable()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_temp_dependent_film_coeff_table'
        # # vba_code = """
        # # Public Function get_temp_dependent_film_coeff_table(abq_film_condition)
        # #     Dim oFilmCoeff (2)
        # #     abq_film_condition.GetTempDependentFilmCoeffTable oFilmCoeff
        # #     get_temp_dependent_film_coeff_table = oFilmCoeff
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_named_film_coeff_amplitude(self, ifilm_amplitude: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNamedFilmCoeffAmplitude(CATBSTR ifilmAmplitude)
                | 
                |     Sets the name of the amplitude that gives the variation of the the film
                |     coefficient with time.
                | 
                |     Parameters:
                | 
                |         ifilmAmplitude
                |             The name of the amplitude that gives the variation of the the film
                |             coefficient with time.

        :param str ifilm_amplitude:
        :rtype: None
        """
        return self.abq_film_condition.SetNamedFilmCoeffAmplitude(ifilm_amplitude)

    def set_named_sink_amplitude(self, isink_amplitude: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetNamedSinkAmplitude(CATBSTR isinkAmplitude)
                | 
                |     Sets the name of the amplitude that contains the variation of the sink
                |     temperature with time.
                | 
                |     Parameters:
                | 
                |         isinkAmplitude
                |             The name of the amplitude that contains the variation of the sink
                |             temperature with time.

        :param str isink_amplitude:
        :rtype: None
        """
        return self.abq_film_condition.SetNamedSinkAmplitude(isink_amplitude)

    def __repr__(self):
        return f'ABQFilmCondition(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class EhmInsertionActPlugMapViewData(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         EHMInsertionActPlugMapViewData
                | 
                | Interface to access Plug Map view data associated to an Insertion
                | activity.
                | 
                | Role: Component that implement DNBIAEHMInsertionActPlugMapViewData is
                | DNBEHMModel.
                | 
                | When using DNBIAEHMInsertionActPlugMapViewData interface in C++, query from
                | interface DNBIEHMInsertionActivity.
                | When using from VB Script, use GetTechnologicalObject to get handle to
                | interface.
                | 
                | PlugMap Data consists of 2 parts namely Connector data & inserted wires
                | data.
                | To get data about inserted wires, first get the number of wires using
                | method
                | get_NumInsertedWires, then set index of wire using put_WireID and then access
                | information about that wire.
                | Please note that default returned string for all PROPERTY of type CATBSTR is
                | "UnSet".
                | 
                | Sample Code in VB Script is as given below
                | '---- InsertionAct is activity for Plug Map view data.
                | Dim InsertionAct As Activity
                | Set InsertionAct = get activity DNBEHMInsertionAct.1
                | Set PlugMapData = InsertionAct.GetTechnologicalObject( "EHMInsertionActPlugMapViewData" )
                | Dim ConnectorName As String
                | ConnectorName = PlugMapData.ConnectorName
                | Dim NumInsertedWires, ii As Integer
                | NumInsertedWires = PlugMapData.NumInsertedWires
                | Dim TerminationName, WireName, ContactName As String
                | For ii = 1 to NumInsertedWires
                | PlugMapData.WireID = ii
                | TerminationName = PlugMapData.TerminationName
                | WireName = PlugMapData.WireName
                | Next
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ehm_insertion_act_plug_map_view_data = com_object

    @property
    def connector_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorName() As CATBSTR (Read Only)
                | 
                |     Gets ConnectorName.
                | 
                |     Parameters:
                | 
                |         oConnectorName
                |             the Connector Name. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ConnectorName

    @property
    def connector_part_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorPartNumber() As CATBSTR (Read Only)
                | 
                |     Gets Connector Part Number.
                | 
                |     Parameters:
                | 
                |         oConnectorPartNumber
                |             the Connector Part Number. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ConnectorPartNumber

    @property
    def connector_ref_designator(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorRefDesignator() As CATBSTR (Read Only)
                | 
                |     Gets Connector Reference Designator.
                | 
                |     Parameters:
                | 
                |         oConnectorRefDesignator
                |             the Connector Reference Designator. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ConnectorRefDesignator

    @property
    def connector_sub_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorSubType() As CATBSTR (Read Only)
                | 
                |     Gets Connector Sub Type.
                | 
                |     Parameters:
                | 
                |         oConnectorSubType
                |             the Connector Sub Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ConnectorSubType

    @property
    def connector_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorType() As CATBSTR (Read Only)
                | 
                |     Gets Connector Type.
                | 
                |     Parameters:
                | 
                |         oConnectorType
                |             the Connector Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ConnectorType

    @property
    def contact_elec_barrel_diameter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactElecBarrelDiameter() As double (Read Only)
                | 
                |     Gets Contact Elec Barrel Diameter.
                | 
                |     Parameters:
                | 
                |         oContactElecBarrelDiameter
                |             the Contact Elec Barrel Diameter. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: float
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactElecBarrelDiameter

    @property
    def contact_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactName() As CATBSTR (Read Only)
                | 
                |     Gets Contact Name.
                | 
                |     Parameters:
                | 
                |         oContactName
                |             the Contact Name. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactName

    @property
    def contact_part_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactPartNumber() As CATBSTR (Read Only)
                | 
                |     Gets Contact Part Number.
                | 
                |     Parameters:
                | 
                |         oContactPartNumber
                |             the Contact Part Number. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactPartNumber

    @property
    def contact_ref_designator(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactRefDesignator() As CATBSTR (Read Only)
                | 
                |     Gets Contact Reference Designator.
                | 
                |     Parameters:
                | 
                |         oContactRefDesignator
                |             the Contact Ref Designator. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactRefDesignator

    @property
    def contact_sub_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactSubType() As CATBSTR (Read Only)
                | 
                |     Gets Contact Sub Type.
                | 
                |     Parameters:
                | 
                |         oContactSubType
                |             the Contact Sub Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactSubType

    @property
    def contact_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ContactType() As CATBSTR (Read Only)
                | 
                |     Gets Contact Type.
                | 
                |     Parameters:
                | 
                |         oContactType
                |             the Contact Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.ContactType

    @property
    def num_inserted_wires(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumInsertedWires() As long (Read Only)
                | 
                |     Gets the number of inserted wires.
                | 
                |     Parameters:
                | 
                |         NumInsertedWires
                |             the number of inserted wires. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the wire ID is set successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: int
        """

        return self.ehm_insertion_act_plug_map_view_data.NumInsertedWires

    @property
    def termination_id_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationIDNumber() As CATBSTR (Read Only)
                | 
                |     Gets Termination ID Number.
                | 
                |     Parameters:
                | 
                |         oTerminationIDNumber.
                |             the Termination ID Number 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationIDNumber

    @property
    def termination_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationName() As CATBSTR (Read Only)
                | 
                |     Gets Termination Name.
                | 
                |     Parameters:
                | 
                |         oTerminationName
                |             the Termination Name. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationName

    @property
    def termination_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationNumber() As CATBSTR (Read Only)
                | 
                |     Gets Termination Number.
                | 
                |     Parameters:
                | 
                |         oTerminationNumber
                |             the Termination Number. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationNumber

    @property
    def termination_ref_designator(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationRefDesignator() As CATBSTR (Read Only)
                | 
                |     Gets Termination Reference Designator.
                | 
                |     Parameters:
                | 
                |         oTerminationRefDesignator
                |             the Termination Ref Designator. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationRefDesignator

    @property
    def termination_sub_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationSubType() As CATBSTR (Read Only)
                | 
                |     Gets Termination Sub Type.
                | 
                |     Parameters:
                | 
                |         oTerminationSubType
                |             the Termination Sub Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationSubType

    @property
    def termination_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TerminationType() As CATBSTR (Read Only)
                | 
                |     Gets Termination Type.
                | 
                |     Parameters:
                | 
                |         oTerminationType
                |             the Termination Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.TerminationType

    @property
    def wire_colour(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireColor() As CATBSTR (Read Only)
                | 
                |     Gets Wire Color.
                | 
                |     Parameters:
                | 
                |         oWireColor
                |             the Wire Color. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireColor

    @property
    def wire_diameter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireDiameter() As double (Read Only)
                | 
                |     Gets Wire Diameter.
                | 
                |     Parameters:
                | 
                |         oWireDiameter
                |             the Wire Diameter. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: float
        """

        return self.ehm_insertion_act_plug_map_view_data.WireDiameter

    @property
    def wire_id(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireID(long iWireID) (Write Only)
                | 
                |     Sets the index of wire.
                | 
                |     Parameters:
                | 
                |         iWireID
                |             Index of wire between 1 & NumInsertedWires associated to an
                |             Insertion Activity. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the wire ID is set successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: int
        """

        return self.ehm_insertion_act_plug_map_view_data.WireID

    @wire_id.setter
    def wire_id(self, value: int):
        """
        :param int value:
        """

        self.ehm_insertion_act_plug_map_view_data.WireID = value

    @property
    def wire_length(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireLength() As double (Read Only)
                | 
                |     Gets Wire Length.
                | 
                |     Parameters:
                | 
                |         oWireLength
                |             the Wire Length. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: float
        """

        return self.ehm_insertion_act_plug_map_view_data.WireLength

    @property
    def wire_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireName() As CATBSTR (Read Only)
                | 
                |     Gets Wire Name.
                | 
                |     Parameters:
                | 
                |         oWireName
                |             the Wire Name. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireName

    @property
    def wire_part_number(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WirePartNumber() As CATBSTR (Read Only)
                | 
                |     Gets Wire Part Number.
                | 
                |     Parameters:
                | 
                |         oWirePartNumber
                |             the Wire Part Number. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WirePartNumber

    @property
    def wire_ref_designator(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireRefDesignator() As CATBSTR (Read Only)
                | 
                |     Gets Wire Reference Designator.
                | 
                |     Parameters:
                | 
                |         oWireRefDesignator
                |             the Wire Ref Designator. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireRefDesignator

    @property
    def wire_separation_code(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireSeparationCode() As CATBSTR (Read Only)
                | 
                |     Gets Wire Separation Code.
                | 
                |     Parameters:
                | 
                |         oWireSeparationCode
                |             the Wire Separation Code. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireSeparationCode

    @property
    def wire_signal_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireSignalID() As CATBSTR (Read Only)
                | 
                |     Gets Wire Signal ID.
                | 
                |     Parameters:
                | 
                |         oWireSignalID
                |             the Wire Signal ID. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireSignalID

    @property
    def wire_sub_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireSubType() As CATBSTR (Read Only)
                | 
                |     Gets Wire Sub Type.
                | 
                |     Parameters:
                | 
                |         oWireSubType
                |             the Wire Sub Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireSubType

    @property
    def wire_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WireType() As CATBSTR (Read Only)
                | 
                |     Gets Wire Type.
                | 
                |     Parameters:
                | 
                |         oWireType
                |             the Wire Type. 
                | 
                |     Returns:
                |         An HRESULT
                |         Legal values:
                | 
                |             S_OK if the Property is returned successfully.
                |             E_FAIL otherwise
                |             .

        :rtype: str
        """

        return self.ehm_insertion_act_plug_map_view_data.WireType

    def __repr__(self):
        return f'EhmInsertionActPlugMapViewData(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abqiaabq_steady_state_lin_dyn_step_basic_vb import \
    ABQIAABQSteadyStateLinDynStepBasicVB


class ABQIAABQSteadyStateLinDynStepSubspaceVB(ABQIAABQSteadyStateLinDynStepBasicVB):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                        ABQAutomationItf.ABQIAABQSteadyStateLinDynStepBasicVB
                |                            ABQIAABQSteadyStateLinDynStepSubspaceVB
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement ABQIAABQSteadyStateLinDynStepSubspace are
                | ...
                | 
                | Do not use the ABQIAABQSteadyStateLinDynStepSubspace interface for such and
                | such ClassReference, Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb = com_object

    @property
    def max_damping_change(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxDampingChange() As double
                | 
                |     Returns or sets Maximum Damping Change.
                | 
                |     Returns:
                |         The Maximum Damping Change. Applicable only for Projection Type = As a function of property changes.

        :rtype: float
        """

        return self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.MaxDampingChange

    @max_damping_change.setter
    def max_damping_change(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.MaxDampingChange = value

    @property
    def max_stiffness_change(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxStiffnessChange() As double
                | 
                |     Returns or sets Maximum Stiffness Change.
                | 
                |     Returns:
                |         The Maximum Stiffness Change. Applicable only for Projection Type = As a function of property changes.

        :rtype: float
        """

        return self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.MaxStiffnessChange

    @max_stiffness_change.setter
    def max_stiffness_change(self, value: float):
        """
        :param float value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.MaxStiffnessChange = value

    @property
    def subspace_friction_damping(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubspaceFrictionDamping() As boolean
                | 
                |     Sets or returns if the Subspace Response.
                | 
                |     Returns:
                |         A boolean specifying whether the Subspace Response is used.

        :rtype: bool
        """

        return self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceFrictionDamping

    @subspace_friction_damping.setter
    def subspace_friction_damping(self, value: bool):
        """
        :param bool value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceFrictionDamping = value

    @property
    def subspace_projection_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubspaceProjectionType() As short
                | 
                |     Returns or sets Subspace Projection Type.
                | 
                |     Returns:
                |         The Subspace Projection Type.
                |
                |         Legal values:
                |          1 - Evaluate at each frequency.
                |          2 - Constant.
                |          3 - Interpolate at eigen frequency.
                |          4 - As a function of property changes.
                |          5 - Interpolate at upper and lower frequency limits.
                |
                |         Example:
                |             This example sets the Subspace Projection Type as Evaluate at each
                |             frequency for abqSSDStep
                | 
                |              abqSSDStep.SubspaceProjectionType = 1

        :rtype: int
        """

        return self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceProjectionType

    @subspace_projection_type.setter
    def subspace_projection_type(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceProjectionType = value

    @property
    def subspace_response(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubspaceResponase() As short
                | 
                |     Returns or sets Subspace Responase.
                | 
                |     Returns:
                |         The Subspace Responase.
                | 
                |           
                |         Legal values:
                |          1 - Real.
                |          2 - Complex.
                |          
                | 
                |         Example:
                |             This example sets the Subspace Responase as Real for
                |             abqSSDStep
                | 
                |              abqSSDStep.SubspaceResponase = 1

        :rtype: int
        """

        return self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceResponase

    @subspace_response.setter
    def subspace_response(self, value: int):
        """
        :param int value:
        """

        self.abqiaabq_steady_state_lin_dyn_step_subspace_vb.SubspaceResponase = value

    def __repr__(self):
        return f'ABQIAABQSteadyStateLinDynStepSubspaceVB(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchComponent
                | 
                | Manage a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_component = com_object

    def create_component_inst(self, i_grr: SchGRRComp, i_db6_axis: tuple, o_new_component: 'SchComponent') -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateComponentInst(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb6Axis,
                | SchComponent oNewComponent)
                | 
                |     Create a component instance. The reference component must exist in current
                |     document
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         iDb6Axis
                |             X-axis of the local axis of the new instance Y-axis of the local
                |             axis of the new instance X-Y coordinates of the orgin of the new instance. This
                |             axis defines the orientation and location of the new instance in space.
                |             Optional (could be NULL). If provided, the instance will be and orientated as
                |             defined. Else (1.0,0.0,0.0,1.0,0.0,0.0) is used 
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(6) As CATSafeArrayVariant
                |          Dim objArg3 As SchComponent
                |           ...
                |          objThisIntf.CreateComponentInstobjArg1,dbVar2,objArg3

        :param SchGRRComp i_grr:
        :param tuple i_db6_axis:
        :param SchComponent o_new_component:
        :rtype: tuple
        """
        return self.sch_component.CreateComponentInst(i_grr.com_object, i_db6_axis, o_new_component.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_component_inst'
        # # vba_code = """
        # # Public Function create_component_inst(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.CreateComponentInst iGRR
        # #     create_component_inst = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_local_reference(self, i_document_to_put_copy_in: Document) -> 'SchComponent':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateLocalReference(Document iDocumentToPutCopyIn) As
                | SchComponent
                | 
                |     Make a local component reference in another document by copying an existing
                |     one in the current document.
                | 
                |     Parameters:
                | 
                |         iDocumentToPutCopyIn
                |             Pointer to the document to make the copy in 
                |         oSchComp
                |             Pointer to the copy. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As Document
                |          Dim objArg2 As SchComponent
                |           ...
                |          Set objArg2 = objThisIntf.CreateLocalReference(objArg1)

        :param Document i_document_to_put_copy_in:
        :rtype: SchComponent
        """
        return SchComponent(self.sch_component.CreateLocalReference(i_document_to_put_copy_in.com_object))

    def flip_connected(self, i_grr: SchGRRComp) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipConnected(SchGRRComp iGRR)
                | 
                |     For component that is connected to another component or is inserted into a
                |     route. This method changes the current connections on this component and
                |     connects the component to the next compatible connector (connectors-pair in
                |     case of inserted component).
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation object. if NULL
                |             the first insert image found will be used. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |           ...
                |          objThisIntf.FlipConnectedobjArg1

        :param SchGRRComp i_grr:
        :rtype: None
        """
        return self.sch_component.FlipConnected(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'flip_connected'
        # # vba_code = """
        # # Public Function flip_connected(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.FlipConnected iGRR
        # #     flip_connected = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def flip_horizontal(self, i_grr: SchGRRComp) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipHorizontal(SchGRRComp iGRR)
                | 
                |     Mirror transform a component's image about the horizontal-axis centered at
                |     the local axis of the component. This component should not be connected to any
                |     other object.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |           ...
                |          objThisIntf.FlipHorizontalobjArg1

        :param SchGRRComp i_grr:
        :rtype: None
        """
        return self.sch_component.FlipHorizontal(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'flip_horizontal'
        # # vba_code = """
        # # Public Function flip_horizontal(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.FlipHorizontal iGRR
        # #     flip_horizontal = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def flip_on_line(self, i_grr: SchGRRComp) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipOnLine(SchGRRComp iGRR)
                | 
                |     Mirror the graphical object of this component. Ths mirror line is the
                |     inserted route segment. The current connections on the component is not
                |     changed. case of inserted component).
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |           ...
                |          objThisIntf.FlipOnLineobjArg1

        :param SchGRRComp i_grr:
        :rtype: None
        """
        return self.sch_component.FlipOnLine(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'flip_on_line'
        # # vba_code = """
        # # Public Function flip_on_line(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.FlipOnLine iGRR
        # #     flip_on_line = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def flip_vertical(self, i_grr: SchGRRComp) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipVertical(SchGRRComp iGRR)
                | 
                |     Mirror transform a component's image about the vertical-axis centered at
                |     the local axis of the component. This component should not be connected to any
                |     other object.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |           ...
                |          objThisIntf.FlipVerticalobjArg1

        :param SchGRRComp i_grr:
        :rtype: None
        """
        return self.sch_component.FlipVertical(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'flip_vertical'
        # # vba_code = """
        # # Public Function flip_vertical(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.FlipVertical iGRR
        # #     flip_vertical = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def insert_into_route_with_info(
            self,
            i_insert_info: AnyObject,
            o_new_component: 'SchComponent',
            o_new_route: SchRoute
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub InsertIntoRouteWithInfo(AnyObject iInsertInfo,
                | SchComponent oNewComponent,
                | SchRoute oNewRoute)
                | 
                |     Insert a component into a route. An internal structure is prerequisite to
                |     calling this method. This structure is obtained from calling
                |     CATISchCompatible::GetBestFitInsertInfo.
                | 
                |     Parameters:
                | 
                |         iInsertInfo
                |             Pointer to an internal class which contains structured information
                |             of a component for placement. This is the output for calling
                |             CATISchCompatible::GetBestFitInsertInfo. 
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |             
                |         oNewRoute
                |             Interface pointer to the new route instance, created when the
                |             component is inserted into the route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchComponent
                |          Dim objArg3 As SchRoute
                |           ...
                |          objThisIntf.InsertIntoRouteWithInfoobjArg1,objArg2,objArg3

        :param AnyObject i_insert_info:
        :param SchComponent o_new_component:
        :param SchRoute o_new_route:
        :rtype: None
        """
        return self.sch_component.InsertIntoRouteWithInfo(
            i_insert_info.com_object,
            o_new_component.com_object,
            o_new_route.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'insert_into_route_with_info'
        # # vba_code = """
        # # Public Function insert_into_route_with_info(sch_component)
        # #     Dim iInsertInfo (2)
        # #     sch_component.InsertIntoRouteWithInfo iInsertInfo
        # #     insert_into_route_with_info = iInsertInfo
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_a_reference(self, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsAReference(boolean oBYes)
                | 
                |     Query whether the component is a reference (as opposed to an
                |     instance).
                | 
                |     Parameters:
                | 
                |         oBYes
                |             If TRUE, the component is a reference. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim bVar1 As boolean
                |           ...
                |          objThisIntf.IsAReferencebVar1

        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.IsAReference(o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_a_reference'
        # # vba_code = """
        # # Public Function is_a_reference(sch_component)
        # #     Dim oBYes (2)
        # #     sch_component.IsAReference oBYes
        # #     is_a_reference = oBYes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_inserted(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsInserted(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether the component is inserted into a route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation.
                |             
                |         oBYes
                |             If TRUE, the component is currently inserted in a route.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.IsInsertedobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.IsInserted(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_inserted'
        # # vba_code = """
        # # Public Function is_inserted(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.IsInserted iGRR
        # #     is_inserted = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_flip_connected(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToFlipConnected(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to connect the component via next compatible
                |     connectors.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToFlipConnectedobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToFlipConnected(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_flip_connected'
        # # vba_code = """
        # # Public Function ok_to_flip_connected(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToFlipConnected iGRR
        # #     ok_to_flip_connected = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_flip_horizontal(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToFlipHorizontal(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to flip the component about the horizontal
                |     axis.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToFlipHorizontalobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToFlipHorizontal(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_flip_horizontal'
        # # vba_code = """
        # # Public Function ok_to_flip_horizontal(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToFlipHorizontal iGRR
        # #     ok_to_flip_horizontal = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_flip_on_line(
            self,
            i_grr: SchGRRComp,
            o_b_yes: bool,
            o_db2_line_pt: SchListOfDoubles,
            o_db2_line_vec: SchListOfDoubles
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToFlipOnLine(SchGRRComp iGRR,
                | boolean oBYes,
                | SchListOfDoubles oDb2LinePt,
                | SchListOfDoubles oDb2LineVec)
                | 
                |     Query whether it is OK to flip the component about the inserted route
                |     segment.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                |         oDb2LinePt
                |             Absolute X-Y coordinates of a point on the segment.
                |             
                |         oDb2LineVec
                |             Absolute X-Y component vector along the segment. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |          Dim objArg3 As SchListOfDoubles
                |          Dim objArg4 As SchListOfDoubles
                |           ...
                |          objThisIntf.OKToFlipOnLineobjArg1,bVar2,objArg3,objArg4

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :param SchListOfDoubles o_db2_line_pt:
        :param SchListOfDoubles o_db2_line_vec:
        :rtype: None
        """
        return self.sch_component.OKToFlipOnLine(
            i_grr.com_object,
            o_b_yes,
            o_db2_line_pt.com_object,
            o_db2_line_vec.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_flip_on_line'
        # # vba_code = """
        # # Public Function ok_to_flip_on_line(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToFlipOnLine iGRR
        # #     ok_to_flip_on_line = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_flip_vertical(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToFlipVertical(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to flip the component about vertical
                |     axis.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to flip the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToFlipVerticalobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToFlipVertical(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_flip_vertical'
        # # vba_code = """
        # # Public Function ok_to_flip_vertical(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToFlipVertical iGRR
        # #     ok_to_flip_vertical = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_place_in_space(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToPlaceInSpace(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether the component can be placed in free space.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, the component can be slided. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToPlaceInSpaceobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToPlaceInSpace(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_place_in_space'
        # # vba_code = """
        # # Public Function ok_to_place_in_space(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToPlaceInSpace iGRR
        # #     ok_to_place_in_space = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_scale(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToScale(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to scale the component.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to scale the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToScaleobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToScale(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_scale'
        # # vba_code = """
        # # Public Function ok_to_scale(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToScale iGRR
        # #     ok_to_scale = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_slide(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToSlide(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether the component can be slided.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, the component can be slided. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToSlideobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToSlide(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_slide'
        # # vba_code = """
        # # Public Function ok_to_slide(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToSlide iGRR
        # #     ok_to_slide = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def ok_to_uninsert(self, i_grr: SchGRRComp, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub OKToUninsert(SchGRRComp iGRR,
                | boolean oBYes)
                | 
                |     Query whether it is OK to uninsert the component.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         oBYes
                |             If TRUE, then it is OK to uninsert the component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.OKToUninsertobjArg1,bVar2

        :param SchGRRComp i_grr:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_component.OKToUninsert(i_grr.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'ok_to_uninsert'
        # # vba_code = """
        # # Public Function ok_to_uninsert(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.OKToUninsert iGRR
        # #     ok_to_uninsert = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def place_in_space(self, i_grr: SchGRRComp, i_db6_axis: tuple, o_new_component: 'SchComponent') -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PlaceInSpace(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb6Axis,
                | SchComponent oNewComponent)
                | 
                |     Place a component in space, unconnected to other objects. It will create
                |     local reference (from a catalog referenced document) if
                |     necessary.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         iDb6Axis[6]
                |             X-axis of the local axis of the new instance Y-axis of the local
                |             axis of the new instance X-Y coordinates of the orgin of the new instance. This
                |             axis defines the orientation and location of the new instance in space.
                |             
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |             
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(6) As CATSafeArrayVariant
                |          Dim objArg3 As SchComponent
                |           ...
                |          objThisIntf.PlaceInSpaceobjArg1,dbVar2,objArg3

        :param SchGRRComp i_grr:
        :param tuple i_db6_axis:
        :param SchComponent o_new_component:
        :rtype: tuple
        """
        return self.sch_component.PlaceInSpace(i_grr.com_object, i_db6_axis, o_new_component.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'place_in_space'
        # # vba_code = """
        # # Public Function place_in_space(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.PlaceInSpace iGRR
        # #     place_in_space = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def place_on_component_with_info(self, i_place_info: AnyObject) -> 'SchComponent':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func PlaceOnComponentWithInfo(AnyObject iPlaceInfo) As
                | SchComponent
                | 
                |     Place a component connected to another component. An internal structure is
                |     prerequisite to calling this method. This structure is obtained from calling
                |     CATISchCompatible::GetBestFitPlaceInfo.
                | 
                |     Parameters:
                | 
                |         iPlaceInfo
                |             Pointer to an internal class which contains structured information
                |             of a component for placement. This is the output for calling
                |             CATISchCompatible::GetBestFitPlaceInfo. 
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchComponent
                |           ...
                |          Set objArg2 = objThisIntf.PlaceOnComponentWithInfo(objArg1)

        :param AnyObject i_place_info:
        :rtype: SchComponent
        """
        return SchComponent(self.sch_component.PlaceOnComponentWithInfo(i_place_info.com_object))

    def place_on_object(
            self,
            i_grr: SchGRRComp,
            i_db6_axis: tuple,
            i_object_to_connect: SchAppConnectable,
            o_new_component: 'SchComponent'
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PlaceOnObject(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb6Axis,
                | SchAppConnectable iObjectToConnect,
                | SchComponent oNewComponent)
                | 
                |     Place a component connected to another component or insert into a
                |     route.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         iDb6Axis[6]
                |             X-axis of the local axis of the new instance Y-axis of the local
                |             axis of the new instance X-Y coordinates of the orgin of the new instance. This
                |             axis defines the orientation and location of the new instance in space.
                |             
                |         iObjectToConnect
                |             Pointer to a component to connect the new instance to or a route
                |             object to insert new component into. 
                |         oNewComponent
                |             Interface pointer to the new component instance placed.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(6) As CATSafeArrayVariant
                |          Dim objArg3 As SchAppConnectable
                |          Dim objArg4 As SchComponent
                |           ...
                |          objThisIntf.PlaceOnObjectobjArg1,dbVar2,objArg3,objArg4

        :param SchGRRComp i_grr:
        :param tuple i_db6_axis:
        :param SchAppConnectable i_object_to_connect:
        :param SchComponent o_new_component:
        :rtype: tuple
        """
        return self.sch_component.PlaceOnObject(
            i_grr.com_object,
            i_db6_axis,
            i_object_to_connect.com_object,
            o_new_component.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'place_on_object'
        # # vba_code = """
        # # Public Function place_on_object(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.PlaceOnObject iGRR
        # #     place_on_object = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def query_connect_ability(self, i_grr: SchGRRComp) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func QueryConnectAbility(SchGRRComp iGRR) As AnyObject
                | 
                |     Find the Schematic component information for placement.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             "Primary" graphical representation will be used. 
                |         oPlaceInfo
                |             Pointer to an internal class which contains structured information
                |             of a component for placement. This is the input for calling
                |             CATISchCompatible::IsComponentCompatible 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim objArg2 As AnyObject
                |           ...
                |          Set objArg2 = objThisIntf.QueryConnectAbility(objArg1)

        :param SchGRRComp i_grr:
        :rtype: AnyObject
        """
        return AnyObject(self.sch_component.QueryConnectAbility(i_grr.com_object))

    def slide(self, i_grr: SchGRRComp, i_db2_pt_to_slide_to: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Slide(SchGRRComp iGRR,
                | CATSafeArrayVariant iDb2PtToSlideTo)
                | 
                |     Slide a component (applicable to inserted component only). The component is
                |     moved along the route and remain inserted.
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                |         iDb2PtToSlideTo[2]
                |             X-Y coordinates of the point to slide the component to.
                |
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |          Dim dbVar2(2) As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SlideobjArg1,dbVar2

        :param SchGRRComp i_grr:
        :param tuple i_db2_pt_to_slide_to:
        :rtype: tuple
        """
        return self.sch_component.Slide(i_grr.com_object, i_db2_pt_to_slide_to)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'slide'
        # # vba_code = """
        # # Public Function slide(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.Slide iGRR
        # #     slide = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def uninsert(self, i_grr: SchGRRComp) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Uninsert(SchGRRComp iGRR)
                | 
                |     Remove all connections of a component with a route. (applicable to inserted
                |     component only).
                | 
                |     Parameters:
                | 
                |         iGRR
                |             Pointer to the component graphical representation. if NULL the
                |             first insert image found will be used. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchComponent
                |          Dim objArg1 As SchGRRComp
                |           ...
                |          objThisIntf.UninsertobjArg1

        :param SchGRRComp i_grr:
        :rtype: None
        """
        return self.sch_component.Uninsert(i_grr.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'uninsert'
        # # vba_code = """
        # # Public Function uninsert(sch_component)
        # #     Dim iGRR (2)
        # #     sch_component.Uninsert iGRR
        # #     uninsert = iGRR
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class Ig2SettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         Ig2SettingAtt
                | 
                | Interface dedicated to modify or read the current settings corresponding to the
                | IG2 Data Exchange
                | 
                | Ensure consistency with the C++ interface to which the work is
                | delegated.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ig2_setting_att = com_object

    @property
    def export_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportMode() As CatIg2ExportModeEnum (Read Only)
                | 
                |     Get the Export Mode option value.
                | 
                |     Parameters:
                | 
                |         oMode
                |             Legal values: An available value of the enum CatIg2ExportModeEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_ig2_export_mode_enum
        :rtype: int
        """

        return self.ig2_setting_att.ExportMode

    @property
    def export_sheets(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportSheets() As CatIg2ExportSheetsEnum (Read
                | Only)
                | 
                |     Get the Exported Sheets option value.
                | 
                |     Parameters:
                | 
                |         oSheets
                |             Legal values: An available value of the enum
                |             CatIg2ExportSheetsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.ig2_setting_att.ExportSheets

    @property
    def import_destination_view(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDestinationView() As CatIg2ImportDestinationViewEnum (Read
                | Only)
                | 
                |     Get the destination view.
                | 
                |     Parameters:
                | 
                |         oDestinationView
                |             Legal values: An available value of the enum
                |             CatIg2ImportDestinationViewEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_ig2_import_destination_view_enum
        :rtype: int
        """

        return self.ig2_setting_att.ImportDestinationView

    @property
    def import_dft_standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDftStandard() As CATBSTR (Read Only)
                | 
                |     Get the name of the Drafting standard, which define the standard of the
                |     resulting CATDrawing file.
                | 
                |     Parameters:
                | 
                |         oDftStandard
                |             the CATBSTR corresponding to the Drafting standard.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: str
        """

        return self.ig2_setting_att.ImportDftStandard

    @property
    def import_dimensions(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDimensions() As CatIg2ImportDimensionsEnum (Read
                | Only)
                | 
                |     Get the Import dimensions option value.
                | 
                |     Parameters:
                | 
                |         oDimensions
                |             Legal values: An available value of the enum
                |             CatIg2ImportDimensionsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_ig2_import_dimensions_enum
        :rtype: int
        """

        return self.ig2_setting_att.ImportDimensions

    @property
    def import_end_points(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportEndPoints() As CatIg2ImportCreateEndPointsEnum (Read
                | Only)
                | 
                |     Get the Create End Points option value.
                | 
                |     Parameters:
                | 
                |         oEndPoints
                |             Legal values: An available value of the enum
                |             CatIg2ImportCreateEndPointsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_ig2_import_create_end_points_enum
        :rtype: int
        """

        return self.ig2_setting_att.ImportEndPoints

    @property
    def import_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportUnit() As CatIg2ImportUnitEnum (Read Only)
                | 
                |     Get the import unit.
                | 
                |     Parameters:
                | 
                |         oUnit
                |             Legal values: An available value of the enum CatIg2ImportUnitEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_ig2_import_unit_enum
        :rtype: int
        """

        return self.ig2_setting_att.ImportUnit

    def get_export_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Mode
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetExportModeInfo(io_admin_level, io_locked)

    def get_export_sheets_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportSheetsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Exported Sheets
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetExportSheetsInfo(io_admin_level, io_locked)

    def get_import_destination_view_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDestinationViewInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the destination view
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetImportDestinationViewInfo(io_admin_level, io_locked)

    def get_import_dft_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDftStandardInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Drafting standard
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetImportDftStandardInfo(io_admin_level, io_locked)

    def get_import_dimensions_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDimensionsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Import dimensions
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetImportDimensionsInfo(io_admin_level, io_locked)

    def get_import_end_points_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportEndPointsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Create End Points
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetImportEndPointsInfo(io_admin_level, io_locked)

    def get_import_unit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportUnitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the import unit
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.ig2_setting_att.GetImportUnitInfo(io_admin_level, io_locked)

    def set_export_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Mode option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetExportModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_mode_lock'
        # # vba_code = """
        # # Public Function set_export_mode_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetExportModeLock iLocked
        # #     set_export_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_sheets_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportSheetsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Exported Sheets option if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetExportSheetsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_sheets_lock'
        # # vba_code = """
        # # Public Function set_export_sheets_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetExportSheetsLock iLocked
        # #     set_export_sheets_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_destination_view_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDestinationViewLock(boolean iLocked)
                | 
                |     Locks or unlocks the import destination view if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetImportDestinationViewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_destination_view_lock'
        # # vba_code = """
        # # Public Function set_import_destination_view_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetImportDestinationViewLock iLocked
        # #     set_import_destination_view_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dft_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDftStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the Drafting standard option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetImportDftStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_dft_standard_lock'
        # # vba_code = """
        # # Public Function set_import_dft_standard_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetImportDftStandardLock iLocked
        # #     set_import_dft_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dimensions_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDimensionsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Import dimensions option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetImportDimensionsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_dimensions_lock'
        # # vba_code = """
        # # Public Function set_import_dimensions_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetImportDimensionsLock iLocked
        # #     set_import_dimensions_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_end_points_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportEndPointsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Create End Points option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetImportEndPointsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_end_points_lock'
        # # vba_code = """
        # # Public Function set_import_end_points_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetImportEndPointsLock iLocked
        # #     set_import_end_points_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_unit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportUnitLock(boolean iLocked)
                | 
                |     Locks or unlocks the import unit option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.ig2_setting_att.SetImportUnitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_unit_lock'
        # # vba_code = """
        # # Public Function set_import_unit_lock(ig2_setting_att)
        # #     Dim iLocked (2)
        # #     ig2_setting_att.SetImportUnitLock iLocked
        # #     set_import_unit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_mode(self, i_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportMode(CatIg2ExportModeEnum iMode)
                | 
                |     Set the Export Mode option value.
                | 
                |     Parameters:
                | 
                |         iMode
                |             Legal values: An available value of the enum CatIg2ExportModeEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_mode: enum cat_ig2_export_mode_enum
        :rtype: None
        """
        return self.ig2_setting_att.set_ExportMode(i_mode)

    def set_export_sheets(self, i_sheets: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportSheets(CatIg2ExportSheetsEnum iSheets)
                | 
                |     set the Exported Sheets option value.
                | 
                |     Parameters:
                | 
                |         iSheets
                |             Legal values: An available value of the enum
                |             CatIg2ExportSheetsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_sheets:
        :rtype: None
        """
        return self.ig2_setting_att.set_ExportSheets(i_sheets)

    def set_import_destination_view(self, i_destination_view: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDestinationView(CatIg2ImportDestinationViewEnum
                | iDestinationView)
                | 
                |     Set the destination view.
                | 
                |     Parameters:
                | 
                |         iDestinationView
                |             Legal values: An available value of the enum
                |             CatIg2ImportDestinationViewEnum 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_destination_view: enum cat_ig2_import_destination_view_enum
        :rtype: None
        """
        return self.ig2_setting_att.set_ImportDestinationView(i_destination_view)

    def set_import_dft_standard(self, i_dft_standard: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDftStandard(CATBSTR iDftStandard)
                | 
                |     Set the name of the Drafting standard, which define the standard of the
                |     resulting CATDrawing file.
                | 
                |     Parameters:
                | 
                |         iDftStandard
                |             the CATBSTR corresponding to the Drafting standard.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dft_standard:
        :rtype: None
        """
        return self.ig2_setting_att.set_ImportDftStandard(i_dft_standard)

    def set_import_dimensions(self, i_dimensions: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDimensions(CatIg2ImportDimensionsEnum
                | iDimensions)
                | 
                |     Set the Import dimensions option value.
                | 
                |     Parameters:
                | 
                |         iDimensions
                |             Legal values: An available value of the enum
                |             CatIg2ImportDimensionsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_dimensions: enum cat_ig2_import_dimensions_enum
        :rtype: None
        """
        return self.ig2_setting_att.set_ImportDimensions(i_dimensions)

    def set_import_end_points(self, i_end_points: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportEndPoints(CatIg2ImportCreateEndPointsEnum
                | iEndPoints)
                | 
                |     Set the Create End Points option value.
                | 
                |     Parameters:
                | 
                |         iEndPoints
                |             Legal values: An available value of the enum
                |             CatIg2ImportCreateEndPointsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_end_points: enum cat_ig2_import_create_end_points_enum
        :rtype: None
        """
        return self.ig2_setting_att.set_ImportEndPoints(i_end_points)

    def set_import_unit(self, i_unit: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportUnit(CatIg2ImportUnitEnum iUnit)
                | 
                |     Set the import unit.
                | 
                |     Parameters:
                | 
                |         iUnit
                |             Legal values: An available value of the enum CatIg2ImportUnitEnum
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_unit: enum cat_ig2_import_unit_enum
        :rtype: None
        """
        return self.ig2_setting_att.set_ImportUnit(i_unit)

    def __repr__(self):
        return f'Ig2SettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.walk_activity import WalkActivity


class AutoWalkActivity(WalkActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             DNBHumanSimInterfaces.WalkActivity
                |                                 AutoWalkActivity
                | 
                | Interface that represents an Auto-Walk activity
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.auto_walk_activity = com_object

    def get_length_in_metre(self, d_length: float, b_curr_manikin_pose: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLengthInMetre(double dLength,
                | boolean bCurrManikinPose)
                | 
                |     This gets the auto walk length in metres
                | 
                |     Parameters:
                | 
                |         bCurrManikinPosition
                |             The bCurrManikinPosition flag is used to obtain the walk length for
                |             autowalk dynamically based on the location of manikin irrespective of its
                |             previous MoveToPosture activity; in a line tracking scenario if the manikin has
                |             a body constraint with a moving object then, the Degree Of Freedom (DOF)of
                |             previous MoveToPosture activity gives only the static walk length and is
                |             incorrect. By default, this value will be taken as FALSE
                |
                |     Returns:
                |         dLength walk length in metre

        :param float d_length:
        :param bool b_curr_manikin_pose:
        :rtype: None
        """
        return self.auto_walk_activity.GetLengthInMetre(d_length, b_curr_manikin_pose)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_length_in_metre'
        # # vba_code = """
        # # Public Function get_length_in_metre(auto_walk_activity)
        # #     Dim dLength (2)
        # #     auto_walk_activity.GetLengthInMetre dLength
        # #     get_length_in_metre = dLength
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AutoWalkActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.tag import Tag
from pycatia.system_interfaces.any_object import AnyObject


class TagFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TagFactory
                | 
                | Interface representing Tag factory.
                | 
                | Role: This allows the creation of a Tag
                | The following code snippet can be used to obtain a TagFactory from a selected
                | TagGroup
                | 
                |  Dim objTagFactory As TagFactory
                |  Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |  Set objTagFactory = ParentObject.GetTechnologicalObject("TagFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tag_factory = com_object

    def create_tag(self, i_tag_name: str, o_tag: Tag) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTag(CATBSTR iTagName,
                | Tag oTag)
                | 
                |     Creates a Tag. Each Tag has a Name and a parent TagGroup.
                | 
                |     Parameters:
                | 
                |         iTagName
                |             Name of the Tag to be created. 
                |         oTag
                |             Newly created Tag. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             Action is successfully created and the interface pointer is
                |             successfully returned
                |         E_FAIL
                |             Action was successfully created, but the interface query
                |             failed
                |         E_NOINTERFACE
                |             Action was successfully created, but the it doesn't implement the
                |             requested interface
                |         E_OUTOFMEMORY
                |             The component allocation failed
                | 
                |     Example:
                |
                |           Dim objTagFactory As TagFactory
                |           ...
                |           Dim objTag As Tag
                |           Dim TagName As String
                |           TagName =  "MY_TAG"
                |           objTagFactory.CreateTag TagName, objTag

        :param str i_tag_name:
        :param Tag o_tag:
        :rtype: None
        """
        return self.tag_factory.CreateTag(i_tag_name, o_tag.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag'
        # # vba_code = """
        # # Public Function create_tag(tag_factory)
        # #     Dim iTagName (2)
        # #     tag_factory.CreateTag iTagName
        # #     create_tag = iTagName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TagFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAppReplace(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppReplace
                | 
                | Manage a schematic component.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_replace = com_object

    def app_ok_to_replace(self, i_sch_object_to_be_replaced_by_this: AnyObject, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOKToReplace(AnyObject iSchObjectToBeReplacedByThis,
                | boolean oBYes)
                | 
                |     Query whether it is OK to replace an existing object (component, route...)
                |     with this object.
                | 
                |     Parameters:
                | 
                |         iSchObjectToBeReplacedByThis
                |             Pointer to the existing object to be replaced by this object.
                |             
                |         oBYes
                |             If TRUE, then it is OK to replace the object. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchAppReplace
                |          Dim objArg1 As AnyObject
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.AppOKToReplaceobjArg1,bVar2

        :param AnyObject i_sch_object_to_be_replaced_by_this:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_replace.AppOKToReplace(i_sch_object_to_be_replaced_by_this.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_ok_to_replace'
        # # vba_code = """
        # # Public Function app_ok_to_replace(sch_app_replace)
        # #     Dim iSchObjectToBeReplacedByThis (2)
        # #     sch_app_replace.AppOKToReplace iSchObjectToBeReplacedByThis
        # #     app_ok_to_replace = iSchObjectToBeReplacedByThis
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_post_replace_process(self, i_sch_object_to_be_replaced_by_this: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppPostReplaceProcess(AnyObject
                | iSchObjectToBeReplacedByThis)
                | 
                |     Post process after replacing an object.
                | 
                |     Parameters:
                | 
                |         iNewObject
                |             The new Application object 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppReplace
                |          Dim objArg1 As AnyObject
                |           ...
                |          objThisIntf.AppPostReplaceProcessobjArg1

        :param AnyObject i_sch_object_to_be_replaced_by_this:
        :rtype: None
        """
        return self.sch_app_replace.AppPostReplaceProcess(i_sch_object_to_be_replaced_by_this.com_object)

    def __repr__(self):
        return f'SchAppReplace(name="{self.name}")'
